==> 11.3.0.tar.gz: lib/XfXWidgets/XElencoItem.dart <==
part of xwidgetbase;

class XElencoItem extends StatefulWidget {
  XElencoItem(
    this.xObjOriginal,
    this.xView, {
    this.funct,
    this.xViewDetts,
    this.xLayout_Item_RowWidgets,
    this.liPopUpMenu_Items,
    Key? key,
    this.childMain,
    this.childDetails,
    this.showingDetails = false,
    this.showMainWithDetails = true,
    this.decorationBackGroundContainer,
    this.changeStatoWithTap = true,
    this.onTapItem,
    this.onLongTapItem,
    this.onDoubleTapItem,
    this.margin,
    this.crossAxisAlignment,
    this.backGroundColor_ChildMain,
    this.backGroundColor_ChildDetails,
    this.iconColor_Collapsed,
    this.iconColor_Expanded,
    this.showTrailingArrow = true,
    this.icon_Active,
    this.icon_Disabled,
    this.height_Icon,
    this.size_Icon,
    this.width_Icon,
    this.childMain_CrossAxisAlignment,
    this.widgets_LeftArea,
    this.edited,
  }) : super(key: key);

  /// default TRUE
  XFDataItem xObjOriginal;
  XView xView;
  XView? xViewDetts;
  void Function()? funct;
  Widget Function(XCol xCol, XFDataItem item)? xLayout_Item_RowWidgets;
  List<XPopUpMenuItem>? liPopUpMenu_Items = List<XPopUpMenuItem>.empty(growable: true);
  bool showMainWithDetails;
  Widget? childMain;
  bool showingDetails;
  Widget? childDetails;
  List<Widget>? widgets_LeftArea;
  bool changeStatoWithTap;
  bool? showTrailingArrow;
  Color? backGroundColor_ChildMain;
  Color? backGroundColor_ChildDetails;
  Color? iconColor_Expanded;
  Color? iconColor_Collapsed;
  double? width_Icon;
  double? height_Icon;
  double? size_Icon;
  ValueNotifier<bool>? edited;
  Decoration? decorationBackGroundContainer;
  EdgeInsetsGeometry? margin;
  CrossAxisAlignment? crossAxisAlignment;
  CrossAxisAlignment? childMain_CrossAxisAlignment;
  IconData? icon_Active;
  IconData? icon_Disabled;
  Function()? onTapItem;
  Function()? onLongTapItem;
  Function()? onDoubleTapItem;
  @override
  _XElencoItemState createState() => _XElencoItemState();
}

class _XElencoItemState extends State<XElencoItem> {
  @override
  void initState() {
    if (widget.edited == null) {
      widget.edited = ValueNotifier(false);
    }
    super.initState();
  }

  Widget xBuilder_childMain() {
    return widget.childMain ?? Container();
  }

  Widget xLayout_Item_RowWidgets(XCol xCol, XFDataItem item, bool noTextWhenCellValueIsNull, {String formatDate = "dd/MM/yy"}) {
    Widget _xContainerOfWidgets;

    if (xCol.dataType == String && xCol.colKey.startsWith("li").not()) {
      _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey] : (noTextWhenCellValueIsNull ? "<No Text>" : ""), maxLines: xCol.multilines ? 3 : 1, style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }
    //WIDGET NEL CASO FOSSE UN DATETIME
    else if (xCol.dataType == DateTime) {
      _xContainerOfWidgets = Text(XUtils.dateToString(item[xCol.colKey] ?? DateTime(1900, 01, 01), format: formatDate), maxLines: 1, style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }
    //WIDGET NEL CASO FOSSE UN DOUBLE
    else if (xCol.dataType == double) {
      if (xCol.format == "C") {
        _xContainerOfWidgets = Text(XUtils.xToCurrency(context, item[xCol.colKey] ?? 0.0), style: XStyles.xStyTextForDescr(Colors.yellow), textAlign: TextAlign.end, overflow: TextOverflow.ellipsis);
        // Se è un un semplice double
      } else {
        _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey].toString() : "0.0", style: XStyles.xStyTextForDescr(Colors.yellow), overflow: TextOverflow.ellipsis);
      }
    }
    //WIDGET NEL CASO FOSSE UN INTERO
    else if (xCol.dataType == int) {
      _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey].toString() : "0", style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);

      //Se fosse una lista e voglio prendere la quantità di oggetti dentro
    } else if (xCol.dataType == bool) {
      _xContainerOfWidgets = Container(
        child: XCheckBoxWidget(
            verticalCheckBoxWidget: true,
            label: xCol.colCaption,
            label_Color: xCol.xmodelXprop.col_Color,
            activeColor: xCol.xmodelXprop.col_Color,
            checkColor: Colors.black,
            value: (item[xCol.colKey] ?? false),
            onChanged: (value) async {
              setState(() {
                widget.funct != null ? widget.funct!() : null;
                widget.edited!.value = true;
                item[xCol.colKey] = value;
              });
            }),
      );
    } else if (xCol.dataType == String && (xCol.colKey.startsWith("li"))) {
      _xContainerOfWidgets = Container();
    } else {
      _xContainerOfWidgets = Text(xCol.headerToolTip + (item[xCol.colKey] != null ? item[xCol.colKey] : (noTextWhenCellValueIsNull ? "<No Text>" : "")), style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }

    //Se la colonna è Width FLEX
    // if (xCol.resizeStyle == 0) {
    //   return Flexible(flex: (xCol.spanX == 0) ? 1 : xCol.spanX, child: Container(margin: EdgeInsets.symmetric(horizontal: 2), child: _xContainerOfWidgets));
    // }
    // //Se la colonna è Width PROPORTIONAL
    // else if (xCol.resizeStyle == 1) {
    //   return Container(constraints: BoxConstraints(minWidth: xCol.minWidth, maxWidth: xCol.maxWidth), margin: EdgeInsets.symmetric(horizontal: 2), child: _xContainerOfWidgets);
    // }
    // //Se la colonna è Width FIX
    // else {
    return Container(width: xCol.width, child: _xContainerOfWidgets);
    // }
  }

  ///Crazione del PopUp Menu passandogli la lista dei XPopUpMenuItem
  Widget xLayout_BTN_Function(XFDataItem item) {
    return (widget.liPopUpMenu_Items == null || widget.liPopUpMenu_Items!.isEmpty)
        ? Container()
        : Container(
            height: 30,
            child: PopupMenuButton(
              padding: EdgeInsets.all(1),
              icon: Icon(Icons.more_vert_outlined),
              itemBuilder: (context) {
                return widget.liPopUpMenu_Items!
                    .map((e) => PopupMenuItem(
                        height: 40,
                        child: XBtnbase(
                          decoration: BoxDecoration(border: Border(bottom: BorderSide(color: Colors.grey[700]!))),
                          height: 40,
                          width: (e.iconImage != null || e.icon != null) ? 250 : 150,
                          label: e.title,
                          icon_WidthArea: 50,
                          label_Style: XStyles.xStyTextForSubLabel(e.color),
                          icon_Widget: e.icon != null ? null : Container(width: 50, child: e.iconImage),
                          icon: e.iconImage != null ? null : e.icon,
                          icon_Size: 23,
                          icon_Color: e.iconImage != null ? null : e.color,
                          toolTip_Message: e.toolTip_Message,
                          onPressed: () => e.onPressed!(context, item),
                        )))
                    .toList();
              },
              iconSize: 22,
            ));
  }

  Widget xLayout_BTN_ExpandedItem(XFDataItem item) {
    return XBtnbase(
      icon: item.isShowDetails ? Icons.keyboard_arrow_up_outlined : Icons.keyboard_arrow_down_outlined,
      elevation: 0,
      height: 40,
      width: 40,
      icon_Color: Brightness.dark == true ? Colors.black : Colors.white,
      backGroundColor: Colors.transparent,
      icon_Size: 30,
      onPressed: () => setState(() => item.isShowDetails = item.isShowDetails.not()),
    );
  }

  Widget? xLayout_RowDetts_Widget(XCol xCol, dynamic item) {
    if (widget.xLayout_Item_RowWidgets != null) {
      return widget.xLayout_Item_RowWidgets!(xCol, item);
    } else {
      return null;
    }
  }

  Widget xLayout_DettsRowsArea(dynamic item) {
    List<Widget> _liDettsWidget = List<Widget>.empty(growable: true);
    var res = widget.xView.cols.firstWhereOrNull((element) {
      return element.colKey.startsWith("li");
    });
    List<dynamic> t = List<dynamic>.empty(growable: true);
    if (res != null) {
      t = item.getProp(res.colKey);
    }
    print(_liDettsWidget.length);
    return (res != null)
        ? Container(
            padding: EdgeInsets.only(bottom: 10, left: 5, right: 5),
            child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: t
                    .map((e) => Row(
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: widget.xViewDetts!.cols
                            .map(
                              (xclCol) => (xLayout_RowDetts_Widget(xclCol, e) != null)
                                  ? (xLayout_RowDetts_Widget(xclCol, t) ?? Container()) //
                                  : xLayout_Item_RowWidgets(xclCol, e, true),
                            )
                            .toList()))
                    .toList())) //
        : Container(padding: EdgeInsets.only(bottom: 10), child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Expanded(child: Text("Nessun elemento", textAlign: TextAlign.center, style: XStyles.xStyTextForDescr()))])); //
  }

  @override
  Widget build(BuildContext context) {
    var x = widget.xView.cols.firstWhereOrNull((element) {
      return element.colKey.startsWith("li");
    });
    var t;
    if (x != null) {
      t = widget.xObjOriginal.getProp(x.colKey);
    }

    List<dynamic> li = List<dynamic>.empty(growable: true);
    li.clear();
    if (x != null) {
      li.addAll(widget.xObjOriginal[x.colKey]);
    } else {
      li = [];
    }
    return Container(
        decoration: widget.decorationBackGroundContainer ?? BoxDecoration(),
        margin: widget.margin ?? EdgeInsets.only(bottom: 2),
        child: Column(crossAxisAlignment: widget.crossAxisAlignment ?? CrossAxisAlignment.center, children: [
          (widget.showMainWithDetails == false && widget.showingDetails == true)
              ? Container()
              : Container(
                  padding: widget.widgets_LeftArea != null ? null : EdgeInsets.all(5),
                  color: widget.backGroundColor_ChildMain,
                  child: Row(crossAxisAlignment: widget.childMain_CrossAxisAlignment ?? CrossAxisAlignment.center, children: [
                    (widget.widgets_LeftArea != null) ? Row(mainAxisSize: MainAxisSize.min, children: widget.widgets_LeftArea ?? []) : Container(width: 0, height: 0),
                    Expanded(
                      child: GestureDetector(
                          onTap: widget.changeStatoWithTap
                              ? widget.onTapItem ??
                                  () {
                                    setState(() => widget.showingDetails = !widget.showingDetails);
                                  }
                              : null,
                          onLongPress: widget.onLongTapItem ?? () {},
                          onDoubleTap: widget.onDoubleTapItem ?? () {},
                          child: Container(
                              color: widget.backGroundColor_ChildMain,
                              padding: EdgeInsets.symmetric(vertical: 6),
                              child: Row(
                                children: [
                                  Expanded(
                                      child: Container(
                                          decoration: widget.xObjOriginal.isShowDetails ? BoxDecoration(border: Border(bottom: BorderSide(width: 1, color: Colors.white))) : null,
                                          padding: EdgeInsets.symmetric(horizontal: 2, vertical: 6),
                                          child: Row(children: [
                                            Expanded(
                                                child: Column(
                                                    crossAxisAlignment: CrossAxisAlignment.start,
                                                    children: widget.xView.cols.groupListsBy((element) => element.originY).entries.map((e) {
                                                      return Wrap(
                                                          spacing: 3,
                                                          runSpacing: 5,
                                                          children: e.value.map((e) {
                                                            return xLayout_Item_RowWidgets(e, widget.xObjOriginal, false);
                                                          }).toList());
                                                    }).toList())),
                                            (li.isNotEmpty && widget.xViewDetts != null) ? Text((widget.xViewDetts!.title ?? "") + ": " + (li.isNotEmpty ? (li.length.toString()) : "0"), style: XStyles.xStyTextForDescr(Colors.white), textAlign: TextAlign.end, overflow: TextOverflow.ellipsis) : Container(),
                                            xLayout_BTN_Function(widget.xObjOriginal),
                                            (t != null && t.isNotEmpty) ? xLayout_BTN_ExpandedItem(widget.xObjOriginal) : Container()
                                          ]))),
                                  (widget.changeStatoWithTap == true && widget.showTrailingArrow == true)
                                      ? Container(
                                          alignment: Alignment.center,
                                          // margin: EdgeInsets.only(top: 10),
                                          padding: EdgeInsets.all(1),
                                          width: widget.width_Icon ?? 40,
                                          height: widget.height_Icon ?? 40,
                                          child: Icon(
                                            widget.showingDetails ? widget.icon_Active ?? Icons.keyboard_arrow_up_outlined : widget.icon_Disabled ?? widget.icon_Active ?? Icons.keyboard_arrow_down_outlined,
                                            color: (widget.showingDetails == false) ? widget.iconColor_Collapsed ?? Colors.grey : widget.iconColor_Expanded ?? Colors.yellow,
                                            size: widget.size_Icon ?? 28,
                                          ))
                                      : Container(width: 0, height: 0)
                                ],
                              ))),
                    )
                  ])),
          Container(
            color: widget.backGroundColor_ChildMain ?? widget.backGroundColor_ChildDetails,
            child: Column(
              children: [widget.showingDetails ? xLayout_DettsRowsArea(widget.xObjOriginal) : Container(), (widget.showingDetails ? widget.childDetails! : Container())],
            ),
          ),
        ]));
  }
}

==> 11.5.9+12.tar.gz: lib/XfXWidgets/XElencoItem.dart <==
part of xwidgetbase;

class XElencoItem extends StatefulWidget {
  XElencoItem(
    this.xObjOriginal,
    this.xView, {
    this.funct,
    this.xViewDetts,
    this.xLayout_Item_RowWidgets,
    this.liPopUpMenu_Items,
    Key? key,
    this.childMain,
    this.childDetails,
    this.showingDetails = false,
    this.showMainWithDetails = true,
    this.decorationBackGroundContainer,
    this.changeStatoWithTap = true,
    this.onTapItem,
    this.onLongTapItem,
    this.onDoubleTapItem,
    this.margin,
    this.crossAxisAlignment,
    this.backGroundColor_ChildMain,
    this.backGroundColor_ChildDetails,
    this.iconColor_Collapsed,
    this.iconColor_Expanded,
    this.showTrailingArrow = true,
    this.icon_Active,
    this.icon_Disabled,
    this.height_Icon,
    this.size_Icon,
    this.width_Icon,
    this.childMain_CrossAxisAlignment,
    this.widgets_LeftArea,
    this.edited,
  }) : super(key: key);

  /// default TRUE
  XFDataItem xObjOriginal;
  XView xView;
  XView? xViewDetts;
  void Function()? funct;
  Widget Function(XCol xCol, XFDataItem item)? xLayout_Item_RowWidgets;
  List<XPopUpMenuItem>? liPopUpMenu_Items = List<XPopUpMenuItem>.empty(growable: true);
  bool showMainWithDetails;
  Widget? childMain;
  bool showingDetails;
  Widget? childDetails;
  List<Widget>? widgets_LeftArea;
  bool changeStatoWithTap;
  bool? showTrailingArrow;
  Color? backGroundColor_ChildMain;
  Color? backGroundColor_ChildDetails;
  Color? iconColor_Expanded;
  Color? iconColor_Collapsed;
  double? width_Icon;
  double? height_Icon;
  double? size_Icon;
  ValueNotifier<bool>? edited;
  Decoration? decorationBackGroundContainer;
  EdgeInsetsGeometry? margin;
  CrossAxisAlignment? crossAxisAlignment;
  CrossAxisAlignment? childMain_CrossAxisAlignment;
  IconData? icon_Active;
  IconData? icon_Disabled;
  Function()? onTapItem;
  Function()? onLongTapItem;
  Function()? onDoubleTapItem;
  @override
  _XElencoItemState createState() => _XElencoItemState();
}

class _XElencoItemState extends State<XElencoItem> {
  @override
  void initState() {
    if (widget.edited == null) {
      widget.edited = ValueNotifier(false);
    }
    super.initState();
  }

  Widget? xBuilder_childMain() {
    return widget.childMain;
  }

  Widget xLayout_Item_RowWidgets(XCol xCol, XFDataItem item, bool noTextWhenCellValueIsNull, {String formatDate = "dd/MM/yy"}) {
    Widget _xContainerOfWidgets;

    if (xCol.dataType == String && xCol.colKey.startsWith("li").not()) {
      _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey] : (noTextWhenCellValueIsNull ? "<No Text>" : ""), maxLines: xCol.multilines ? 3 : 1, style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }
    //WIDGET NEL CASO FOSSE UN DATETIME
    else if (xCol.dataType == DateTime) {
      _xContainerOfWidgets = Text(XUtils.dateToString(item[xCol.colKey] ?? DateTime(1900, 01, 01), format: formatDate), maxLines: 1, style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }
    //WIDGET NEL CASO FOSSE UN DOUBLE
    else if (xCol.dataType == double) {
      if (xCol.format == "C") {
        _xContainerOfWidgets = Text(XUtils.xToCurrency(context, item[xCol.colKey] ?? 0.0), style: XStyles.xStyTextForDescr(Colors.yellow), textAlign: TextAlign.end, overflow: TextOverflow.ellipsis);
        // Se è un un semplice double
      } else {
        _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey].toString() : "0.0", style: XStyles.xStyTextForDescr(Colors.yellow), overflow: TextOverflow.ellipsis);
      }
    }
    //WIDGET NEL CASO FOSSE UN INTERO
    else if (xCol.dataType == int) {
      _xContainerOfWidgets = Text(item[xCol.colKey] != null ? item[xCol.colKey].toString() : "0", style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);

      //Se fosse una lista e voglio prendere la quantità di oggetti dentro
    } else if (xCol.dataType == bool) {
      _xContainerOfWidgets = Container(
        child: XCheckBoxWidget(
            verticalCheckBoxWidget: true,
            label: xCol.colCaption,
            label_Color: xCol.xmodelXprop.col_Color,
            activeColor: xCol.xmodelXprop.col_Color,
            checkColor: Colors.black,
            value: (item[xCol.colKey] ?? false),
            onChanged: (value) async {
              setState(() {
                widget.funct != null ? widget.funct!() : null;
                widget.edited!.value = true;
                item[xCol.colKey] = value;
              });
            }),
      );
    } else if (xCol.dataType == String && (xCol.colKey.startsWith("li"))) {
      _xContainerOfWidgets = Container();
    } else {
      _xContainerOfWidgets = Text(xCol.headerToolTip + (item[xCol.colKey] != null ? item[xCol.colKey] : (noTextWhenCellValueIsNull ? "<No Text>" : "")), style: XStyles.xStyTextForDescr(Colors.white), overflow: TextOverflow.ellipsis);
    }

    //Se la colonna è Width FLEX
    // if (xCol.resizeStyle == 0) {
    //   return Flexible(flex: (xCol.spanX == 0) ? 1 : xCol.spanX, child: Container(margin: EdgeInsets.symmetric(horizontal: 2), child: _xContainerOfWidgets));
    // }
    // //Se la colonna è Width PROPORTIONAL
    // else if (xCol.resizeStyle == 1) {
    //   return Container(constraints: BoxConstraints(minWidth: xCol.minWidth, maxWidth: xCol.maxWidth), margin: EdgeInsets.symmetric(horizontal: 2), child: _xContainerOfWidgets);
    // }
    // //Se la colonna è Width FIX
    // else {
    return Container(width: xCol.width, child: _xContainerOfWidgets);
    // }
  }

  ///Crazione del PopUp Menu passandogli la lista dei XPopUpMenuItem
  Widget xLayout_BTN_Function(XFDataItem item) {
    return (widget.liPopUpMenu_Items == null || widget.liPopUpMenu_Items!.isEmpty)
        ? Container()
        : Container(
            height: 30,
            child: PopupMenuButton(
              padding: EdgeInsets.all(1),
              icon: Icon(Icons.more_vert_outlined),
              itemBuilder: (context) {
                return widget.liPopUpMenu_Items!
                    .map((e) => PopupMenuItem(
                        height: 40,
                        child: XBtnbase(
                          decoration: BoxDecoration(border: Border(bottom: BorderSide(color: Colors.grey[700]!))),
                          height: 40,
                          width: (e.iconImage != null || e.icon != null) ? 250 : 150,
                          label: e.title,
                          icon_WidthArea: 50,
                          label_Style: XStyles.xStyTextForSubLabel(e.color),
                          icon_Widget: e.icon != null ? null : Container(width: 50, child: e.iconImage),
                          icon: e.iconImage != null ? null : e.icon,
                          icon_Size: 23,
                          icon_Color: e.iconImage != null ? null : e.color,
                          toolTip_Message: e.toolTip_Message,
                          onPressed: () => e.onPressed!(context, item),
                        )))
                    .toList();
              },
              iconSize: 22,
            ));
  }

  Widget xLayout_BTN_ExpandedItem(XFDataItem item) {
    return XBtnbase(
      icon: item.isShowDetails ? Icons.keyboard_arrow_up_outlined : Icons.keyboard_arrow_down_outlined,
      elevation: 0,
      height: 40,
      width: 40,
      icon_Color: Brightness.dark == true ? Colors.black : Colors.white,
      backGroundColor: Colors.transparent,
      icon_Size: 30,
      onPressed: () => setState(() => item.isShowDetails = item.isShowDetails.not()),
    );
  }

  Widget? xLayout_RowDetts_Widget(XCol xCol, dynamic item) {
    if (widget.xLayout_Item_RowWidgets != null) {
      return widget.xLayout_Item_RowWidgets!(xCol, item);
    } else {
      return null;
    }
  }

  Widget xLayout_DettsRowsArea(dynamic item) {
    List<Widget> _liDettsWidget = List<Widget>.empty(growable: true);
    var res = widget.xView.cols.firstWhereOrNull((element) {
      return element.colKey.startsWith("li");
    });
    List<dynamic> t = List<dynamic>.empty(growable: true);
    if (res != null) {
      t = item.getProp(res.colKey);
    }
    print(_liDettsWidget.length);
    return (res != null)
        ? Container(
            padding: EdgeInsets.only(bottom: 10, left: 5, right: 5),
            child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: t
                    .map((e) => Row(
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: widget.xViewDetts!.cols
                            .map(
                              (xclCol) => (xLayout_RowDetts_Widget(xclCol, e) != null)
                                  ? (xLayout_RowDetts_Widget(xclCol, t) ?? Container()) //
                                  : xLayout_Item_RowWidgets(xclCol, e, true),
                            )
                            .toList()))
                    .toList())) //
        : Container(padding: EdgeInsets.only(bottom: 10), child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Expanded(child: Text("Nessun elemento", textAlign: TextAlign.center, style: XStyles.xStyTextForDescr()))])); //
  }

  @override
  Widget build(BuildContext context) {
    var x = widget.xView.cols.firstWhereOrNull((element) {
      return element.colKey.startsWith("li");
    });
    var t;
    if (x != null) {
      t = widget.xObjOriginal.getProp(x.colKey);
    }

    List<dynamic> li = List<dynamic>.empty(growable: true);
    li.clear();
    if (x != null) {
      li.addAll(widget.xObjOriginal[x.colKey]);
    } else {
      li = [];
    }
    return Container(
        decoration: widget.decorationBackGroundContainer ?? BoxDecoration(),
        margin: widget.margin ?? EdgeInsets.only(bottom: 2),
        child: Column(crossAxisAlignment: widget.crossAxisAlignment ?? CrossAxisAlignment.center, children: [
          (widget.showMainWithDetails == false && widget.showingDetails == true)
              ? Container()
              : Container(
                  padding: widget.widgets_LeftArea != null ? null : EdgeInsets.all(5),
                  color: widget.backGroundColor_ChildMain,
                  child: Row(crossAxisAlignment: widget.childMain_CrossAxisAlignment ?? CrossAxisAlignment.center, children: [
                    (widget.widgets_LeftArea != null) ? Row(mainAxisSize: MainAxisSize.min, children: widget.widgets_LeftArea ?? []) : Container(width: 0, height: 0),
                    Expanded(
                      child: GestureDetector(
                          onTap: widget.changeStatoWithTap
                              ? widget.onTapItem ??
                                  () {
                                    setState(() => widget.showingDetails = !widget.showingDetails);
                                  }
                              : null,
                          onLongPress: () async {
                            if (widget.onLongTapItem != null) {
                              widget.onLongTapItem!();
                            }
                          },
                          onDoubleTap: widget.onDoubleTapItem ?? () {},
                          child: xBuilder_childMain() != null
                              ? xBuilder_childMain()
                              : Container(
                                  color: widget.backGroundColor_ChildMain,
                                  padding: EdgeInsets.symmetric(vertical: 6),
                                  child: Row(
                                    children: [
                                      Expanded(
                                          child: Container(
                                              decoration: widget.xObjOriginal.isShowDetails ? BoxDecoration(border: Border(bottom: BorderSide(width: 1, color: Colors.white))) : null,
                                              padding: EdgeInsets.symmetric(horizontal: 2, vertical: 6),
                                              child: Row(children: [
                                                Expanded(
                                                    child: Column(
                                                        crossAxisAlignment: CrossAxisAlignment.start,
                                                        children: widget.xView.cols.groupListsBy((element) => element.originY).entries.map((e) {
                                                          return Wrap(
                                                              spacing: 3,
                                                              runSpacing: 5,
                                                              children: e.value.map((e) {
                                                                return xLayout_Item_RowWidgets(e, widget.xObjOriginal, false);
                                                              }).toList());
                                                        }).toList())),
                                                (li.isNotEmpty && widget.xViewDetts != null) ? Text((widget.xViewDetts!.title ?? "") + ": " + (li.isNotEmpty ? (li.length.toString()) : "0"), style: XStyles.xStyTextForDescr(Colors.white), textAlign: TextAlign.end, overflow: TextOverflow.ellipsis) : Container(),
                                                xLayout_BTN_Function(widget.xObjOriginal),
                                                (t != null && t.isNotEmpty) ? xLayout_BTN_ExpandedItem(widget.xObjOriginal) : Container()
                                              ]))),
                                      (widget.changeStatoWithTap == true && widget.showTrailingArrow == true)
                                          ? Container(
                                              alignment: Alignment.center,
                                              // margin: EdgeInsets.only(top: 10),
                                              padding: EdgeInsets.all(1),
                                              width: widget.width_Icon ?? 40,
                                              height: widget.height_Icon ?? 40,
                                              child: Icon(
                                                widget.showingDetails ? widget.icon_Active ?? Icons.keyboard_arrow_up_outlined : widget.icon_Disabled ?? widget.icon_Active ?? Icons.keyboard_arrow_down_outlined,
                                                color: (widget.showingDetails == false) ? widget.iconColor_Collapsed ?? Colors.grey : widget.iconColor_Expanded ?? Colors.yellow,
                                                size: widget.size_Icon ?? 28,
                                              ))
                                          : Container(width: 0, height: 0)
                                    ],
                                  ))),
                    )
                  ])),
          Container(
            color: widget.backGroundColor_ChildMain ?? widget.backGroundColor_ChildDetails,
            child: Column(
              children: [widget.showingDetails ? xLayout_DettsRowsArea(widget.xObjOriginal) : Container(), (widget.showingDetails ? widget.childDetails! : Container())],
            ),
          ),
        ]));
  }

  Future<bool> xCMD_DeleteFromList(XFDataItem item, String title) async {
    bool res = await showDialog(
        barrierDismissible: false,
        context: context,
        builder: (builder) {
          return XAlertDialog(
            btnNO_label: "NO",
            btnYES_label: "SI",
            btnYES_OnPressed: () => Navigator.pop(context, true),
            btnNO_OnPressed: () => Navigator.pop(context, false),
            title_Text: title,
            title_Style: XStyles.xStyTextForSubLabel(Colors.yellow),
          );
        });
    return res;
  }
}
